@@ -6,7 +6,7 @@
     FLINT is free software: you can redistribute it and/or modify it under
     the terms of the GNU Lesser General Public License (LGPL) as published
     by the Free Software Foundation; either version 2.1 of the License, or
-    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+    (at your option) any later version.  See <https://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -26,10 +26,8 @@ void gcd_check(
     const char * name)
 {
     int res;
-    fmpq_t lc;
     fmpq_mpoly_t ca, cb, cg, u, v, w;
 
-    fmpq_init(lc);
     fmpq_mpoly_init(ca, ctx);
     fmpq_mpoly_init(cb, ctx);
     fmpq_mpoly_init(cg, ctx);
@@ -82,8 +80,7 @@ void gcd_check(
         goto cleanup;
     }
 
-    fmpq_mpoly_get_term_coeff_fmpq(lc, g, 0, ctx);
-    if (!fmpq_is_one(lc))
+    if (!fmpq_mpoly_is_monic(g, ctx))
     {
         printf("FAIL\n");
         flint_printf("Check gcd is monic\n"
@@ -270,7 +267,6 @@ void gcd_check(
 
 cleanup:
 
-    fmpq_clear(lc);
     fmpq_mpoly_clear(ca, ctx);
     fmpq_mpoly_clear(cb, ctx);
     fmpq_mpoly_clear(cg, ctx);
